@@ -5,9 +5,9 @@ from imageutils import newimage
 import platform
 
 try:
-    from urllib.parse import urlparse
+    from urllib.parse import urlparse, urldefrag
 except ImportError:
-    from urlparse import urlparse
+    from urlparse import urlparse, urldefrag
 
 try:
     import tkinter as tk
@@ -89,7 +89,7 @@ class HtmlFrame(ttk.Frame):
         self.html.done_loading_func = self.done_loading
 
         self.message_func(
-            "Welcome to TkinterWeb 3.5! \nhttps://github.com/Andereoo/TkinterWeb")
+            "Welcome to TkinterWeb 3.9! \nhttps://github.com/Andereoo/TkinterWeb")
 
         self.message_func(
             "Debugging messages are enabled. \nUse the parameter `messages_enabled = False` when calling HtmlFrame() to disable these messages.")
@@ -144,22 +144,12 @@ class HtmlFrame(ttk.Frame):
         try:
             method = method.upper()
             parsed = urlparse(url)
-            parsed2 = urlparse(self.current_url)
 
-            if parsed.scheme == "file":
-                netloc = parsed.path
-            else:
-                netloc = parsed.netloc
-            if parsed2.scheme == "file":
-                netloc2 = parsed2.path
-            else:
-                netloc2 = parsed2.netloc
             if method == "GET":
                 url = str(url) + str(data)
-
             # if url is different than the current one, load the new site.
-            if force or (method == "POST") or not ((netloc == netloc2) and (parsed.path == parsed2.path) and (parsed.query == parsed2.query)):
-                self.message_func("Connecting to {0}.".format(netloc))
+            if force or (method == "POST") or (urldefrag(url).url != urldefrag(self.current_url).url):
+                self.message_func("Connecting to {0}.".format(parsed.netloc))
                 if (parsed.scheme == "file") or (not self.html.caches_enabled):
                     data, newurl, filetype = download(
                         url, data, method, decode)
